# coding: utf-8

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import edgegallery_face_recognition
from edgegallery_face_recognition.api.upload_api import UploadApi  # noqa: E501
from edgegallery_face_recognition.rest import ApiException


class TestUploadApi(unittest.TestCase):
    """UploadApi unit test stubs"""

    def setUp(self):
        self.api = UploadApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_upload_post(self):
        """Test case for upload_post

        upload images  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
