from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from edgegallery_sdk_face_recognition.api.default_api import DefaultApi
from edgegallery_sdk_face_recognition.api.recognition_api import RecognitionApi
from edgegallery_sdk_face_recognition.api.upload_api import UploadApi
from edgegallery_sdk_face_recognition.api.video_api import VideoApi