# coding: utf-8

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import edgegallery_face_recognition
from edgegallery_face_recognition.models.body2 import Body2  # noqa: E501
from edgegallery_face_recognition.rest import ApiException


class TestBody2(unittest.TestCase):
    """Body2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBody2(self):
        """Test Body2"""
        # FIXME: construct object with mandatory attributes with example values
        # model = edgegallery_face_recognition.models.body2.Body2()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
