# coding: utf-8

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import
# python 2 and python 3 compatibility library
import requests



class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, url=None):
        if url is None:
            url = "face-recognition:9999/v1/face-recognition"
        self.url = url

    def root_get(self):  # noqa: E501
        """helloworld  # noqa: E501

        test  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        r = requests.get(self.url)
        return r.headers

    def root_get_with_http_info(self):  # noqa: E501
        """helloworld  # noqa: E501

        test  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        r = requests.get(self.url)
        return r.text


