# coding: utf-8

# flake8: noqa

"""
    face_recognition

    face_recognition  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from edgegallery_sdk_face_recognition.api.default_api import DefaultApi
from edgegallery_sdk_face_recognition.api.recognition_api import RecognitionApi
from edgegallery_sdk_face_recognition.api.upload_api import UploadApi
from edgegallery_sdk_face_recognition.api.video_api import VideoApi

